==> mx-packageinstaller-pkglist_19.05.20.tar.xz: all/Chinese_CN_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Chinese_CN_Thunderbird
</name>

<description>
   <am>Chinese_simplified localisation of Thunderbird</am>
   <ar>Chinese_simplified localisation of Thunderbird</ar>
   <bg>Chinese_simplified localisation of Thunderbird</bg>
   <ca>Localització de Thunderbird en Xinès simplificat</ca>
   <cs>Chinese_simplified localisation of Thunderbird</cs>
   <da>Kinesisk (forenklet) oversættelse af Thunderbird</da>
   <de>Chinesische (vereinfacht) Lokalisierung von Thunderbird</de>
   <el>Κινεζικός εντοπισμός του Thunderbird</el>
   <en>Chinese_simplified localisation of Thunderbird</en>
   <es>Localización Chino simplificado de Thunderbird</es>
   <et>Chinese_simplified localisation of Thunderbird</et>
   <eu>Chinese_simplified localisation of Thunderbird</eu>
   <fa>Chinese_simplified localisation of Thunderbird</fa>
   <fi>Chinese_simplified localisation of Thunderbird</fi>
   <fr>Localisation chinois-simplifié pour Thunderbird</fr>
   <he_IL>Chinese_simplified localisation of Thunderbird</he_IL>
   <hi>Chinese_simplified localisation of Thunderbird</hi>
   <hr>Chinese_simplified localisation of Thunderbird</hr>
   <hu>Chinese_simplified localisation of Thunderbird</hu>
   <id>Chinese_simplified localisation of Thunderbird</id>
   <is>Chinese_simplified localisation of Thunderbird</is>
   <it>Localizzazione in Cinese_semplificato di Thunderbird</it>
   <ja_JP>Chinese_simplified localisation of Thunderbird</ja_JP>
   <ja>Chinese_simplified localisation of Thunderbird</ja>
   <kk>Chinese_simplified localisation of Thunderbird</kk>
   <ko>Chinese_simplified localisation of Thunderbird</ko>
   <lt>Chinese_simplified localisation of Thunderbird</lt>
   <mk>Chinese_simplified localisation of Thunderbird</mk>
   <nb>Chinese_simplified localisation of Thunderbird</nb>
   <nl>Vereenvoudigd Chinese lokalisatie van Thunderbird</nl>
   <pl>Chiński uproszczony lokalizacja Thunderbirda</pl>
   <pt_BR>Chinês_simplificado Localização para Thunderbird</pt_BR>
   <pt>Chinês_simplificado Localização para Thunderbird</pt>
   <ro>Chinese_simplified localisation of Thunderbird</ro>
   <ru>Chinese_simplified localisation of Thunderbird</ru>
   <sk>Chinese_simplified localisation of Thunderbird</sk>
   <sl>Chinese_simplified localisation of Thunderbird</sl>
   <sq>Chinese_simplified localisation of Thunderbird</sq>
   <sr>Chinese_simplified localisation of Thunderbird</sr>
   <sv>Kinesisk_förenklad lokalisering av Thunderbird</sv>
   <tr>Chinese_simplified localisation of Thunderbird</tr>
   <uk>Chinese_simplified локалізація Thunderbird</uk>
   <zh_CN>Chinese_simplified localisation of Thunderbird</zh_CN>
   <zh_TW>Chinese_simplified localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
thunderbird-l10n-zh-cn
lightning-l10n-zh-cn
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
thunderbird-l10n-zh-cn
lightning-l10n-zh-cn
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_21.03.02.tar.xz: all/Chinese_CN_Thunderbird.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Chinese_CN_Thunderbird
</name>

<description>
   <am>Chinese_simplified localisation of Thunderbird</am>
   <ar>Chinese_simplified localisation of Thunderbird</ar>
   <bg>Chinese_simplified localisation of Thunderbird</bg>
   <bn>Chinese_simplified localisation of Thunderbird</bn>
   <ca>Localització de Thunderbird en Xinès simplificat</ca>
   <cs>Chinese_simplified localisation of Thunderbird</cs>
   <da>Kinesisk (forenklet) oversættelse af Thunderbird</da>
   <de>Chinesische (vereinfacht) Lokalisierung von Thunderbird</de>
   <el>Κινεζικός εντοπισμός του Thunderbird</el>
   <en>Chinese_simplified localisation of Thunderbird</en>
   <es>Localización Chino simplificado de Thunderbird</es>
   <et>Chinese_simplified localisation of Thunderbird</et>
   <eu>Chinese_simplified localisation of Thunderbird</eu>
   <fa>Chinese_simplified localisation of Thunderbird</fa>
   <fil_PH>Chinese_simplified localisation of Thunderbird</fil_PH>
   <fi>Chinese_simplified localisation of Thunderbird</fi>
   <fr>Localisation chinois-simplifié pour Thunderbird</fr>
   <he_IL>Chinese_simplified localisation of Thunderbird</he_IL>
   <hi>Chinese_simplified localisation of Thunderbird</hi>
   <hr>Chinese_simplified localisation of Thunderbird</hr>
   <hu>Chinese_simplified localisation of Thunderbird</hu>
   <id>Chinese_simplified localisation of Thunderbird</id>
   <is>Chinese_simplified localisation of Thunderbird</is>
   <it>Localizzazione in Cinese_semplificato di Thunderbird</it>
   <ja_JP>Chinese_simplified localisation of Thunderbird</ja_JP>
   <ja>Chinese_simplified localisation of Thunderbird</ja>
   <kk>Chinese_simplified localisation of Thunderbird</kk>
   <ko>Chinese_simplified localisation of Thunderbird</ko>
   <lt>Chinese_simplified localisation of Thunderbird</lt>
   <mk>Chinese_simplified localisation of Thunderbird</mk>
   <mr>Chinese_simplified localisation of Thunderbird</mr>
   <nb>Chinese_simplified localisation of Thunderbird</nb>
   <nl>Vereenvoudigd Chinese lokalisatie van Thunderbird</nl>
   <pl>Chiński uproszczony lokalizacja Thunderbirda</pl>
   <pt_BR>Chinês_simplificado Localização para Thunderbird</pt_BR>
   <pt>Chinês_simplificado Localização para Thunderbird</pt>
   <ro>Chinese_simplified localisation of Thunderbird</ro>
   <ru>Chinese_simplified localisation of Thunderbird</ru>
   <sk>Chinese_simplified localisation of Thunderbird</sk>
   <sl>Chinese_simplified localisation of Thunderbird</sl>
   <sq>Chinese_simplified localisation of Thunderbird</sq>
   <sr>Chinese_simplified localisation of Thunderbird</sr>
   <sv>Kinesisk_förenklad lokalisering av Thunderbird</sv>
   <tr>Thunderbird'ün Basitleştirilmiş_Çince yerelleştirmesi</tr>
   <uk>Chinese_simplified локалізація Thunderbird</uk>
   <vi>Chinese_simplified localisation of Thunderbird</vi>
   <zh_CN>Chinese_simplified localisation of Thunderbird</zh_CN>
   <zh_TW>Chinese_simplified localisation of Thunderbird</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
thunderbird-l10n-zh-cn
lightning-l10n-zh-cn
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
thunderbird-l10n-zh-cn
lightning-l10n-zh-cn
</uninstall_package_names>
</app>
